@@ -1,3 +1,4 @@
+# -*- encoding: utf-8 -*-
 #
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -14,14 +15,13 @@
 
 import re
 
-from keystonemiddleware import auth_token
-from oslo_config import cfg
-from oslo_log import log as logging
-from oslo_utils import importutils
+from keystoneclient.middleware import auth_token
+from oslo.config import cfg
 from pecan import hooks
 
 from solum.common import context
-from solum.i18n import _
+from solum.openstack.common.gettextutils import _
+from solum.openstack.common import log as logging
 
 
 LOG = logging.getLogger(__name__)
@@ -35,21 +35,9 @@ AUTH_OPTS = [
                 'via keystone. Default value is True.'),
 ]
 
-
-def list_opts():
-    yield None, AUTH_OPTS
-
-
 CONF = cfg.CONF
 CONF.register_opts(AUTH_OPTS)
-
-PUBLIC_ENDPOINTS = [
-    '^/?$',
-    '^/v[0-9]+/?$',
-    '^/v[0-9]+/triggers',
-    '^/camp/platform_endpoints',
-    '^/camp/camp_v1_1_endpoint'
-]
+CONF.register_opts(auth_token.opts, group=OPT_GROUP_NAME)
 
 
 def install(app, conf):
@@ -65,29 +53,20 @@ def install(app, conf):
     return app
 
 
-class AuthHelper(object):
-    """Helper methods for Auth."""
-
-    def __init__(self):
-        endpoints_pattern = '|'.join(pe for pe in PUBLIC_ENDPOINTS)
-        self._public_endpoints_regexp = re.compile(endpoints_pattern)
-
-    def is_endpoint_public(self, path):
-        return self._public_endpoints_regexp.match(path)
-
-
 class AuthProtocolWrapper(auth_token.AuthProtocol):
     """A wrapper on Keystone auth_token AuthProtocol.
 
     Does not perform verification of authentication tokens for pub routes in
-    the API. Public routes are those defined by PUBLIC_ENDPOINTS
+    the API. Public routes are those which Uri starts with
+    '/{version_number}/public/'
 
     """
 
     def __call__(self, env, start_response):
         path = env.get('PATH_INFO')
-        if AUTH.is_endpoint_public(path):
-            return self._app(env, start_response)
+        regexp = re.compile('^/v[0-9]+/public/')
+        if regexp.match(path):
+            return self.app(env, start_response)
         return super(AuthProtocolWrapper, self).__call__(env, start_response)
 
 
@@ -96,8 +75,9 @@ class AuthInformationHook(hooks.PecanHook):
     def before(self, state):
         if not CONF.get('enable_authentication'):
             return
-        # Skip authentication for public endpoints
-        if AUTH.is_endpoint_public(state.request.path):
+        #Do not proceed for triggers as they use non authenticated service
+        regexp = re.compile('^/v[0-9]+/public/')
+        if regexp.match(state.request.path):
             return
 
         headers = state.request.headers
@@ -110,12 +90,10 @@ class AuthInformationHook(hooks.PecanHook):
 
         project_id = headers.get('X-Project-Id')
         user_name = headers.get('X-User-Name', '')
-        tenant_name = headers.get('X-Project')
 
         domain = headers.get('X-Domain-Name')
         project_domain_id = headers.get('X-Project-Domain-Id', '')
         user_domain_id = headers.get('X-User-Domain-Id', '')
-        password = headers.get('X-Password', '')
 
         # Get the auth token
         try:
@@ -125,16 +103,19 @@ class AuthInformationHook(hooks.PecanHook):
         except ValueError:
             LOG.debug("No auth token found in the request.")
             raise Exception('Not authorized')
-        auth_url = headers.get('X-Auth-Url')
-        if auth_url is None:
-            importutils.import_module('keystonemiddleware.auth_token')
-            auth_url = cfg.CONF.keystone_authtoken.www_authenticate_uri
 
-        auth_token_info = state.request.environ.get('keystone.token_info')
+        service_catalog = None
+        if headers.get('X-Service-Catalog') is not None:
+            try:
+                # We will not parse service catalog here
+                # service_catalog will contain json formatted string
+                service_catalog = headers.get('X-Service-Catalog')
+            except ValueError:
+                raise Exception(
+                    _('Invalid service catalog json.'))
         identity_status = headers.get('X-Identity-Status')
         if identity_status == 'Confirmed':
             ctx = context.RequestContext(auth_token=recv_auth_token,
-                                         auth_token_info=auth_token_info,
                                          user=user_id,
                                          tenant=project_id,
                                          domain=domain,
@@ -142,9 +123,7 @@ class AuthInformationHook(hooks.PecanHook):
                                          project_domain=project_domain_id,
                                          user_name=user_name,
                                          roles=roles,
-                                         auth_url=auth_url,
-                                         password=password,
-                                         tenant_name=tenant_name)
+                                         service_catalog=service_catalog)
             state.request.security_context = ctx
         else:
             LOG.debug("The provided identity is not confirmed.")
@@ -160,9 +139,6 @@ class AuthInformationHook(hooks.PecanHook):
             # Fallback to deprecated role header:
             roles = req.headers.get('X-Role', '')
             if roles:
-                LOG.warning(_("X-Roles is missing. Using deprecated X-Role "
-                              "header"))
+                LOG.warn(_("X-Roles is missing. Using deprecated X-Role "
+                           "header"))
         return [r.strip() for r in roles.split(',')]
-
-
-AUTH = AuthHelper()
