@@ -18,12 +18,8 @@ import wsme
 import wsmeext.pecan as wsme_pecan
 
 from solum.api.controllers.v1.datamodel import assembly
-import solum.api.controllers.v1.userlog as userlog_controller
 from solum.api.handlers import assembly_handler
 from solum.common import exception
-from solum.common import policy
-from solum.common import request
-from solum.i18n import _
 from solum import objects
 
 
@@ -34,45 +30,29 @@ class AssemblyController(rest.RestController):
         super(AssemblyController, self).__init__()
         self._id = assembly_id
 
-    @pecan.expose()
-    def _lookup(self, primary_key, *remainder):
-        if remainder and not remainder[-1]:
-            remainder = remainder[:-1]
-        if primary_key == 'logs':
-            logs = userlog_controller.UserlogsController(self._id)
-            return logs, remainder
-
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_controller_exception
     @wsme_pecan.wsexpose(assembly.Assembly)
     def get(self):
         """Return this assembly."""
-        policy.check('show_assembly',
-                     pecan.request.security_context)
-        request.check_request_for_https()
         handler = assembly_handler.AssemblyHandler(
             pecan.request.security_context)
-        host_url = pecan.request.application_url.rstrip('/')
-        return assembly.Assembly.from_db_model(handler.get(self._id), host_url)
+        return assembly.Assembly.from_db_model(handler.get(self._id),
+                                               pecan.request.host_url)
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_controller_exception
     @wsme_pecan.wsexpose(assembly.Assembly, body=assembly.Assembly)
     def put(self, data):
         """Modify this assembly."""
-        policy.check('update_assembly',
-                     pecan.request.security_context)
         handler = assembly_handler.AssemblyHandler(
             pecan.request.security_context)
         res = handler.update(self._id,
                              data.as_dict(objects.registry.Assembly))
-        host_url = pecan.request.application_url.rstrip('/')
-        return assembly.Assembly.from_db_model(res, host_url)
+        return assembly.Assembly.from_db_model(res, pecan.request.host_url)
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_controller_exception
     @wsme_pecan.wsexpose(status_code=204)
     def delete(self):
         """Delete this assembly."""
-        policy.check('delete_assembly',
-                     pecan.request.security_context)
         handler = assembly_handler.AssemblyHandler(
             pecan.request.security_context)
         return handler.delete(self._id)
@@ -87,45 +67,33 @@ class AssembliesController(rest.RestController):
             remainder = remainder[:-1]
         return AssemblyController(assembly_id), remainder
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_controller_exception
     @wsme_pecan.wsexpose(assembly.Assembly, body=assembly.Assembly,
                          status_code=201)
     def post(self, data):
         """Create a new assembly."""
-        policy.check('create_assembly', pecan.request.security_context)
-        host_url = pecan.request.application_url.rstrip('/')
         js_data = data.as_dict(objects.registry.Assembly)
         if data.plan_uri is not wsme.Unset:
             plan_uri = data.plan_uri
-            if plan_uri.startswith(host_url):
+            if plan_uri.startswith(pecan.request.host_url):
                 pl_uuid = plan_uri.split('/')[-1]
-                pl = objects.registry.Plan.get_by_uuid(
-                    pecan.request.security_context, pl_uuid)
+                pl = objects.registry.Plan.get_by_uuid(None, pl_uuid)
                 js_data['plan_id'] = pl.id
             else:
                 # TODO(asalkeld) we are not hosting the plan so
                 # download the plan and insert it into our db.
-                raise exception.BadRequest(reason=_(
-                    'The plan was not hosted in solum'))
-
-        if js_data.get('plan_id') is None:
-            raise exception.BadRequest(reason=_(
-                'The plan was not given or could not be found'))
+                pass
 
         handler = assembly_handler.AssemblyHandler(
             pecan.request.security_context)
         return assembly.Assembly.from_db_model(
-            handler.create(js_data), host_url)
+            handler.create(js_data), pecan.request.host_url)
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_controller_exception
     @wsme_pecan.wsexpose([assembly.Assembly])
     def get_all(self):
         """Return all assemblies, based on the query provided."""
-        policy.check('get_assemblies',
-                     pecan.request.security_context)
-        request.check_request_for_https()
         handler = assembly_handler.AssemblyHandler(
             pecan.request.security_context)
-        host_url = pecan.request.application_url.rstrip('/')
-        return [assembly.Assembly.from_db_model(assm, host_url)
+        return [assembly.Assembly.from_db_model(assm, pecan.request.host_url)
                 for assm in handler.get_all()]
