@@ -12,14 +12,10 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import string
-
 import wsme
 from wsme import types as wtypes
 
 from solum.api.controllers.v1.datamodel import types as api_types
-from solum.i18n import _
-from solum import objects
 
 TAGS = (TYPE, COMPILER_VERSION, RUNTIME_VERSION, IMPLEMENTATION,
         BUILD_TOOL, OS_PLATFORM, ATTRIBUTE, DESCRIPTION) = (
@@ -29,12 +25,6 @@ TAGS = (TYPE, COMPILER_VERSION, RUNTIME_VERSION, IMPLEMENTATION,
             'solum::lp::attribute::', 'solum::lp::description::')
 
 
-STATE_KIND = wtypes.Enum(str, *objects.image.States.values())
-IMAGE_KIND = wtypes.Enum(str, 'auto', 'qcow2', 'docker')
-SOURCE_KIND = wtypes.Enum(str, 'auto', 'heroku',
-                          'dib', 'dockerfile')
-
-
 class BuildTool(wtypes.Base):
     """A build tool representation."""
 
@@ -60,25 +50,6 @@ class LanguagePack(api_types.Base):
     refer: https://etherpad.openstack.org/p/Solum-Language-pack-json-format
     """
 
-    def __init__(self, **kwds):
-        self.__name = wsme.Unset
-        super(LanguagePack, self).__init__(**kwds)
-
-    def get_name(self):
-        return self.__name
-
-    def set_name(self, value):
-        if len(value) > 100:
-            raise ValueError(_('Names must not be longer than 100 '
-                               'characters'))
-        allowed_chars = string.ascii_lowercase + string.digits + '-_'
-        for ch in value:
-            if ch not in allowed_chars:
-                raise ValueError(_('Names must only contain a-z,0-9,-,_'))
-        self.__name = value
-
-    name = wtypes.wsproperty(str, get_name, set_name, mandatory=True)
-
     language_pack_type = wtypes.text
     """Type of the language pack. Identifies the language supported by the
     language pack. This attribute value will use the
@@ -120,37 +91,6 @@ class LanguagePack(api_types.Base):
     attributes designed by language pack creator.
     """
 
-    source_uri = wtypes.text
-    """The URI of the app/element."""
-
-    source_format = SOURCE_KIND
-    """The source repository format."""
-
-    status = STATE_KIND
-    """The state of the image. """
-
-    base_image_id = wtypes.text
-    """The id (in glance) of the image to customize."""
-
-    image_format = IMAGE_KIND
-    """The image format."""
-
-    created_image_id = wtypes.text
-    """The id of the created image in glance."""
-
-    lp_metadata = wtypes.text
-    """The languagepack meta data."""
-
-    """Parameters that can be used as part of lp building process."""
-    lp_params = wtypes.DictType(
-        wtypes.text,
-        wtypes.DictType(wtypes.text,
-                        api_types.MultiType(
-                            wtypes.text,
-                            int,
-                            bool,
-                            float)))
-
     @classmethod
     def from_image(cls, image, host_url):
         as_dict = {}
@@ -213,7 +153,7 @@ class LanguagePack(api_types.Base):
         if ptfm is not wsme.Unset and 'OS' in ptfm and 'version' in ptfm:
             tags.append(OS_PLATFORM + ptfm['OS'] + '::' + ptfm['version'])
         if self.build_tool_chain is not wsme.Unset:
-            for key, value in self.attributes.items():
+            for key, value in self.attributes.iteritems():
                 tags.append(ATTRIBUTE + key + '::' + value)
         # TODO(julienvey) parse specific attributes for image creation from
         # self.attributes, such as image_format...
@@ -221,18 +161,14 @@ class LanguagePack(api_types.Base):
 
     @classmethod
     def sample(cls):
-        return cls(uri='http://example.com/v1/images/b3e0d79',
-                   source_uri='git://example.com/project/app.git',
-                   source_format='heroku',
-                   name='php-web-app',
-                   type='languagepack',
-                   description='A php web application',
-                   tags=['group_xyz'],
+        return cls(uri='http://example.com/v1/language_packs/123456abcdef',
+                   name='language-pack',
+                   type='service',
+                   description=('Base Java LP with Java version 1.4-1.7.'
+                                ' Supports ant, maven.'),
                    project_id='1dae5a09ef2b4d8cbf3594b0eb4f6b94',
                    user_id='55f41cf46df74320b9486a35f5d28a11',
-                   base_image_id='4dae5a09ef2b4d8cbf3594b0eb4f6b94',
-                   created_image_id='4afasa09ef2b4d8cbf3594b0ec4f6b94',
-                   image_format='docker',
+                   tags=['group_xyz'],
                    language_pack_name='java-1.4-1.7',
                    language_pack_type='org.openstack.solum.Java',
                    language_pack_id='123456789abcdef',
@@ -240,7 +176,7 @@ class LanguagePack(api_types.Base):
                    runtime_versions=['1.4', '1.6', '1.7'],
                    language_implementation='Sun',
                    build_tool_chain=[BuildTool(type='ant', version='1.7'),
-                                     BuildTool(type='maven', version='1.2')],
+                        BuildTool(type='maven', version='1.2')],
                    os_platform={'OS': 'Ubuntu', 'version': '12.04'},
                    attributes={'optional_attr1': 'value',
                                'admin_email': 'someadmin@somewhere.com'},
