@@ -17,19 +17,16 @@ from wsme import types as wtypes
 import wsmeext.pecan as wsme_pecan
 
 from solum.api.controllers import common_types
-from solum.api.controllers.v1 import app
 from solum.api.controllers.v1 import assembly
 from solum.api.controllers.v1 import component
 from solum.api.controllers.v1.datamodel import types as api_types
 from solum.api.controllers.v1 import extension
-from solum.api.controllers.v1 import infrastructure
 from solum.api.controllers.v1 import language_pack
 from solum.api.controllers.v1 import operation
-from solum.api.controllers.v1 import pipeline
 from solum.api.controllers.v1 import plan
+from solum.api.controllers.v1 import public
 from solum.api.controllers.v1 import sensor
 from solum.api.controllers.v1 import service
-from solum.api.controllers.v1 import trigger
 from solum.common import exception
 from solum import version
 
@@ -59,24 +56,9 @@ class Platform(api_types.Base):
     extensions_uri = common_types.Uri
     "URI to extensions."
 
-    operations_uri = common_types.Uri
-    "URI to operations."
-
-    sensors_uri = common_types.Uri
-    "URI to sensors."
-
     language_packs_uri = common_types.Uri
     "URI to language packs."
 
-    pipelines_uri = common_types.Uri
-    "URI to pipelines."
-
-    triggers_uri = common_types.Uri
-    "URI to triggers."
-
-    infrastructure_uri = common_types.Uri
-    "URI to infrastructure."
-
     @classmethod
     def sample(cls):
         return cls(uri='http://example.com/v1',
@@ -92,21 +74,14 @@ class Platform(api_types.Base):
                    services_uri='http://example.com:9777/v1/services',
                    components_uri='http://example.com:9777/v1/components',
                    extensions_uri='http://example.com:9777/v1/extensions',
-                   operations_uri='http://example.com:9777/v1/operations',
-                   sensors_uri='http://example.com:9777/v1/sensors',
                    language_packs_uri=(
-                       'http://example.com:9777/v1/language_packs'),
-                   pipelines_uri='http://example.com:9777/v1/pipelines',
-                   triggers_uri='http://example.com:9777/v1/triggers',
-                   infrastructure_uri=(
-                       'http://example.com:9777/v1/infrastructure'))
+                       'http://example.com:9777/v1/language_packs'))
 
 
 class Controller(object):
     """Version 1 API controller root."""
 
     plans = plan.PlansController()
-    apps = app.AppsController()
     assemblies = assembly.AssembliesController()
     services = service.ServicesController()
     components = component.ComponentsController()
@@ -114,11 +89,9 @@ class Controller(object):
     operations = operation.OperationsController()
     sensors = sensor.SensorsController()
     language_packs = language_pack.LanguagePacksController()
-    pipelines = pipeline.PipelinesController()
-    triggers = trigger.TriggerController()
-    infrastructure = infrastructure.InfrastructureController()
+    public = public.PublicController()
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_controller_exception
     @wsme_pecan.wsexpose(Platform)
     def index(self):
         host_url = '%s/%s' % (pecan.request.host_url, 'v1')
@@ -128,14 +101,8 @@ class Controller(object):
                         description='solum native implementation',
                         implementation_version=version.version_string(),
                         plans_uri='%s/plans' % host_url,
-                        apps_uri='%s/apps' % host_url,
                         assemblies_uri='%s/assemblies' % host_url,
                         services_uri='%s/services' % host_url,
                         components_uri='%s/components' % host_url,
                         extensions_uri='%s/extensions' % host_url,
-                        operations_uri='%s/operations' % host_url,
-                        sensors_uri='%s/sensors' % host_url,
-                        language_packs_uri='%s/language_packs' % host_url,
-                        pipelines_uri='%s/pipelines' % host_url,
-                        triggers_uri='%s/triggers' % host_url,
-                        infrastructure_uri='%s/infrastructure' % host_url)
+                        language_packs_uri='%s/language_packs' % host_url)
