@@ -15,34 +15,35 @@
 
 import os
 
-from oslo_config import cfg
-from oslo_db import options
-from oslo_db.sqlalchemy.migration_cli import manager
-from oslo_log import log as logging
+from oslo.config import cfg
+
+from solum.openstack.common.db.sqlalchemy.migration_cli \
+    import manager as migration_manager
+from solum.openstack.common.db.sqlalchemy import session
+
 
-LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 
 
-def do_version(mgr):
-    print('Current DB revision is %s' % mgr.version())
+def do_version(manager):
+    print('Current DB revision is %s' % manager.version())
 
 
-def do_upgrade(mgr):
-    mgr.upgrade(CONF.command.revision)
+def do_upgrade(manager):
+    manager.upgrade(CONF.command.revision)
 
 
-def do_downgrade(mgr):
-    mgr.downgrade(CONF.command.revision)
+def do_downgrade(manager):
+    manager.downgrade(CONF.command.revision)
 
 
-def do_stamp(mgr):
-    mgr.stamp(CONF.command.revision)
+def do_stamp(manager):
+    manager.stamp(CONF.command.revision)
 
 
-def do_revision(mgr):
-    mgr.revision(message=CONF.command.message,
-                 autogenerate=CONF.command.autogenerate)
+def do_revision(manager):
+    manager.revision(message=CONF.command.message,
+                     autogenerate=CONF.command.autogenerate)
 
 
 def add_command_parsers(subparsers):
@@ -68,22 +69,22 @@ def add_command_parsers(subparsers):
 
 
 def get_manager():
-    if cfg.CONF.database.connection is None:
-        raise ValueError(
-            'Database connection not set in /etc/solum/solum.conf')
-
-    alembic_path = os.path.abspath(
-        os.path.join(os.path.dirname(__file__),
-                     '..', 'objects', 'sqlalchemy',
-                     'migration', 'alembic.ini'))
-    migrate_path = os.path.abspath(
-        os.path.join(os.path.dirname(__file__),
-                     '..', 'objects', 'sqlalchemy',
-                     'migration', 'alembic_migrations'))
+    CONF.import_opt('connection',
+                    'solum.openstack.common.db.sqlalchemy.session',
+                    group='database')
+    session.set_defaults(sql_connection=CONF.database.connection,
+                         sqlite_db='')
+    session.get_session(mysql_traditional_mode=True)
+    alembic_path = os.path.join(os.path.dirname(__file__),
+                                '..', 'objects', 'sqlalchemy',
+                                'migration', 'alembic.ini')
+    migrate_path = os.path.join(os.path.dirname(__file__),
+                                '..', 'objects', 'sqlalchemy',
+                                'migration', 'alembic_migrations')
     migration_config = {'alembic_ini_path': alembic_path,
-                        'alembic_repo_path': migrate_path,
-                        'db_url': CONF.database.connection}
-    return manager.MigrationManager(migration_config)
+                        'migration_repo_path': migrate_path,
+                        'alembic_repo_path': migrate_path}
+    return migration_manager.MigrationManager(migration_config)
 
 
 def main():
@@ -92,9 +93,5 @@ def main():
                                     help='Available commands',
                                     handler=add_command_parsers)
     CONF.register_cli_opt(command_opt)
-
-    # set_defaults() is called to register the db options.
-    options.set_defaults(CONF)
-
     CONF(project='solum')
     CONF.command.func(get_manager())
