@@ -14,22 +14,20 @@
 
 """Common RPC service and API tools for Solum."""
 
-import eventlet
-from oslo_config import cfg
-import oslo_messaging as messaging
-from oslo_messaging.rpc import dispatcher
-from oslo_serialization import jsonutils
+from oslo.config import cfg
+from oslo import messaging
 
 import solum.common.context
-from solum import objects
+from solum.openstack.common import jsonutils
 
-
-# NOTE(paulczar):
-# Ubuntu 14.04 forces librabbitmq when kombu is used
-# Unfortunately it forces a version that has a crash
-# bug.  Calling eventlet.monkey_patch() tells kombu
-# to use libamqp instead.
-eventlet.monkey_patch()
+# NOTE(asalkeld):
+# The solum.openstack.common.rpc entries are for compatability
+# with devstack rpc_backend configuration values.
+TRANSPORT_ALIASES = {
+    'solum.openstack.common.rpc.impl_kombu': 'rabbit',
+    'solum.openstack.common.rpc.impl_qpid': 'qpid',
+    'solum.openstack.common.rpc.impl_zmq': 'zmq',
+}
 
 
 class JsonPayloadSerializer(messaging.NoOpSerializer):
@@ -65,17 +63,14 @@ class Service(object):
 
     def __init__(self, topic, server, handlers):
         serializer = RequestContextSerializer(JsonPayloadSerializer())
-        transport = messaging.get_rpc_transport(cfg.CONF)
+        transport = messaging.get_transport(cfg.CONF,
+                                            aliases=TRANSPORT_ALIASES)
         # TODO(asalkeld) add support for version='x.y'
         target = messaging.Target(topic=topic, server=server)
-        access_policy = dispatcher.DefaultRPCAccessPolicy
         self._server = messaging.get_rpc_server(transport, target, handlers,
-                                                executor='threading',
-                                                serializer=serializer,
-                                                access_policy=access_policy)
+                                                serializer=serializer)
 
     def serve(self):
-        objects.load()
         self._server.start()
         self._server.wait()
 
@@ -84,7 +79,8 @@ class API(object):
     def __init__(self, transport=None, context=None, topic=None):
         serializer = RequestContextSerializer(JsonPayloadSerializer())
         if transport is None:
-            transport = messaging.get_rpc_transport(cfg.CONF)
+            transport = messaging.get_transport(cfg.CONF,
+                                                aliases=TRANSPORT_ALIASES)
         self._context = context
         if topic is None:
             topic = ''
