@@ -25,17 +25,9 @@ class AssemblyList(list, base.CrudListMixin):
 
 
 class States(object):
-    QUEUED = 'QUEUED'
-    UNIT_TESTING = 'UNIT_TESTING'
-    UNIT_TESTING_FAILED = 'UNIT_TESTING_FAILED'
-    UNIT_TESTING_PASSED = 'UNIT_TESTING_PASSED'
+    PENDING = 'PENDING'
     BUILDING = 'BUILDING'
-    BUILT = 'BUILT'
     DEPLOYING = 'DEPLOYING'
     ERROR = 'ERROR'
     READY = 'READY'
-    DELETING = 'DELETING'
-    ERROR_STACK_DELETE_FAILED = 'ERROR_STACK_DELETE_FAILED'
     ERROR_STACK_CREATE_FAILED = 'ERROR_STACK_CREATE_FAILED'
-    ERROR_CODE_DEPLOYMENT = 'ERROR_CODE_DEPLOYMENT'
-    STARTING_APP = 'STARTING_APP'
