@@ -22,19 +22,3 @@ class Image(base.CrudMixin):
 
 class ImageList(list, base.CrudListMixin):
     """List of images."""
-
-
-class States(object):
-    QUEUED = 'QUEUED'
-    BUILDING = 'BUILDING'
-    ERROR = 'ERROR'
-    READY = 'READY'
-
-    @classmethod
-    def as_dict(cls):
-        return dict((k, v) for k, v in cls.__dict__.items()
-                    if k[:2] != '__' and k not in ('values', 'as_dict'))
-
-    @classmethod
-    def values(cls):
-        return cls.as_dict().values()
