@@ -12,9 +12,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import uuid
-
 import sqlalchemy as sa
+import uuid
 
 from solum import objects
 from solum.objects import component as abstract
@@ -33,13 +32,11 @@ class Component(sql.Base, abstract.Component):
     project_id = sa.Column(sa.String(36))
     user_id = sa.Column(sa.String(36))
     name = sa.Column(sa.String(100))
-    component_type = sa.Column(sa.String(100))
     description = sa.Column(sa.String(255))
     tags = sa.Column(sa.Text)
     assembly_id = sa.Column(sa.Integer, sa.ForeignKey('assembly.id'))
     parent_component_id = sa.Column(sa.Integer, sa.ForeignKey('component.id'))
     resource_uri = sa.Column(sa.String(1024))
-    heat_stack_id = sa.Column(sa.String(36))
 
     @property
     def assembly_uuid(self):
@@ -57,19 +54,16 @@ class Component(sql.Base, abstract.Component):
         return ['assembly_uuid']
 
     @staticmethod
-    def assign_and_create(ctxt, assem, name, type, description, resource_uri,
-                          stack_id):
+    def assign_and_create(ctxt, assem, name, description, resource_uri):
         """Helper function to make creating components easier."""
         comp = objects.registry.Component()
         comp.uuid = str(uuid.uuid4())
         comp.name = name
-        comp.component_type = type
         comp.description = description
         comp.assembly_id = assem.id
         comp.user_id = ctxt.user
         comp.project_id = ctxt.tenant
         comp.resource_uri = resource_uri
-        comp.heat_stack_id = stack_id
         comp.create(ctxt)
         return comp
 
