@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -29,8 +31,8 @@ class TestServiceHandler(base.BaseTestCase):
         handler = service_handler.ServiceHandler(self.ctx)
         res = handler.get('test_id')
         self.assertIsNotNone(res)
-        get_by_uuid = mock_registry.Service.get_by_uuid
-        get_by_uuid.assert_called_once_with(self.ctx, 'test_id')
+        mock_registry.Service.get_by_uuid.\
+            assert_called_once_with(self.ctx, 'test_id')
 
     def test_get_all(self, mock_registry):
         mock_registry.ServiceList.get_all.return_value = {}
@@ -41,10 +43,15 @@ class TestServiceHandler(base.BaseTestCase):
 
     def test_update(self, mock_registry):
         data = {'name': 'new_name'}
+        db_obj = fakes.FakeService()
+        mock_registry.Service.get_by_uuid.return_value = db_obj
         handler = service_handler.ServiceHandler(self.ctx)
-        handler.update('test_id', data)
-        mock_registry.Service.update_and_save.assert_called_once_with(
-            self.ctx, 'test_id', data)
+        res = handler.update('test_id', data)
+        self.assertEqual(db_obj.user_id, res.user_id)
+        db_obj.update.assert_called_once_with(data)
+        db_obj.save.assert_called_once_with(self.ctx)
+        mock_registry.Service.get_by_uuid.assert_called_once_with(self.ctx,
+                                                                  'test_id')
 
     def test_create(self, mock_registry):
         data = {'name': 'new_name',
@@ -55,7 +62,7 @@ class TestServiceHandler(base.BaseTestCase):
         res = handler.create(data)
         db_obj.update.assert_called_once_with(data)
         db_obj.create.assert_called_once_with(self.ctx)
-        self.assertEqual(db_obj, res)
+        self.assertEqual(res, db_obj)
 
     def test_delete(self, mock_registry):
         db_obj = fakes.FakeService()
