@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+#
 # Copyright 2013 - Noorul Islam K M
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -12,24 +14,14 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo_config import cfg
-from oslotest import base
-import testscenarios
+from oslo.config import cfg
 
-from solum.common import policy
+from solum.openstack.common import test
 
 
-class BaseTestCase(testscenarios.WithScenarios, base.BaseTestCase):
+class BaseTestCase(test.BaseTestCase):
     """Test base class."""
 
     def setUp(self):
         super(BaseTestCase, self).setUp()
         self.addCleanup(cfg.CONF.reset)
-
-    def policy(self, rules, default_rule='allow', overwrite=True):
-        # Inject an allow and deny rule
-        rules['allow'] = '@'
-        rules['deny'] = '!'
-
-        # Set the rules
-        policy.set_rules(rules, default_rule, overwrite)
