@@ -25,40 +25,36 @@ class TestComponent(base.BaseTestCase):
         super(TestComponent, self).setUp()
         self.db = self.useFixture(utils.Database())
         self.ctx = utils.dummy_context()
-        self.data_assembly = [
-            {'project_id': self.ctx.project_id,
-             'uuid': 'ce43e347f0b0422825245b3e5f140a81cef6e65b',
-             'user_id': 'fred',
-             'name': 'assembly1',
-             'description': 'test assembly',
-             'trigger_id': 'trigger-uuid-1234',
-             'tags': 'assembly tags',
-             'plan_id': 'plan_id_1',
-             'status': 'Building',
-             'application_uri': 'http://192.168.78.21:5000'}]
+        self.data_assembly = \
+            [{'project_id': 'project_id_blah',
+              'uuid': 'ce43e347f0b0422825245b3e5f140a81cef6e65b',
+              'user_id': 'fred',
+              'name': 'assembly1',
+              'description': 'test assembly',
+              'trigger_id': 'trigger-uuid-1234',
+              'tags': 'assembly tags',
+              'plan_id': 'plan_id_1',
+              'status': 'Building',
+              'application_uri': 'http://192.168.78.21:5000'}]
         utils.create_models_from_data(assembly.Assembly, self.data_assembly,
                                       self.ctx)
 
-        self.data = [{'project_id': self.ctx.project_id,
+        self.data = [{'project_id': 'project_id_blah',
                       'user_id': 'fred',
                       'uuid': 'ce43e347f0b0422825245b3e5f140a81cef6e65b',
                       'name': 'component_no_assembly',
-                      'component_type': 'xyz',
                       'description': 'test component',
                       'parent_component_id': '87d98s',
-                      'tags': 'component tags',
-                      'heat_stack_id': '4c712026-dcd5-4664-90b8-0915494c1332'},
-                     {'project_id': self.ctx.project_id,
+                      'tags': 'component tags'},
+                     {'project_id': 'project_id_dep',
                       'user_id': 'fred',
                       'uuid': '70763488-72e0-44ac-a612-e94bf5488555',
                       'name': 'component_assembly',
-                      'component_type': 'xyz',
                       'description': 'test component',
                       'assembly_uuid': 'ce43e347f0b042282524'
                                        '5b3e5f140a81cef6e65b',
                       'parent_component_id': '87d98s',
-                      'tags': 'component tags',
-                      'heat_stack_id': '4c712026-dcd5-4664-90b8-0915494c1332'}]
+                      'tags': 'component tags'}]
         utils.create_models_from_data(component.Component, self.data, self.ctx)
 
     def test_objects_registered(self):
