@@ -20,6 +20,7 @@ Tests for the sqlalchemy solum 'objects' implementation
 """
 
 import datetime
+import uuid
 
 import testtools
 from testtools import matchers
@@ -29,8 +30,6 @@ from solum import objects
 from solum.tests import base as tests
 from solum.tests import utils
 
-from oslo_utils import uuidutils
-
 
 class TestObjectsSqlalchemy(tests.BaseTestCase):
     def setUp(self):
@@ -72,7 +71,7 @@ class TestObjectsSqlalchemy(tests.BaseTestCase):
     def test_object_persist_and_retrieve(self):
         component = objects.registry.Component()
         self.assertIsNotNone(component)
-        component.uuid = uuidutils.generate_uuid()
+        component.uuid = str(uuid.uuid4())
         component.name = 'abc'
         component.description = '1-2-3-4'
         component.plan_id = 1
@@ -87,8 +86,8 @@ class TestObjectsSqlalchemy(tests.BaseTestCase):
         self.assertEqual(component.description, component2.description)
 
         # visible via direct query
-        dsession = utils.get_dummy_session()
-        query = dsession.query(component.__class__).filter_by(id=component.id)
+        query = utils.get_dummy_session().query(component.__class__)\
+            .filter_by(id=component.id)
         component3 = query.first()
         self.assertIsNotNone(component3)
         self.assertEqual(component3.id, component3.id)
@@ -96,14 +95,14 @@ class TestObjectsSqlalchemy(tests.BaseTestCase):
         # visible via get_all
         components = objects.registry.ComponentList.get_all(None)
         exists = [item for item in components if item.id == component.id]
-        self.assertGreater(len(exists), 0)
+        self.assertTrue(len(exists) > 0)
 
     def test_object_mutate(self):
         begin = datetime.datetime.utcnow()
 
         component = objects.registry.Component()
         self.assertIsNotNone(component)
-        component.uuid = uuidutils.generate_uuid()
+        component.uuid = str(uuid.uuid4())
         component.plan_id = 1
         component.create(self.ctx)
 
