@@ -15,21 +15,18 @@
 import tempfile
 
 import fixtures
-from oslo_config import cfg
-from oslo_db import options
+from oslo.config import cfg
 
 from solum.common import context
 from solum import objects
 from solum.objects.sqlalchemy import models
+from solum.openstack.common.db.sqlalchemy import session
 
 CONF = cfg.CONF
 
 
-def dummy_context(user='test_username', tenant_id='fake_project_id',
-                  user_name='usr_name'):
-    return context.RequestContext(user=user,
-                                  tenant=tenant_id,
-                                  user_name=user_name)
+def dummy_context(user='test_username', tenant_id='test_tenant_id'):
+    return context.RequestContext(user=user, tenant=tenant_id)
 
 
 class Database(fixtures.Fixture):
@@ -41,26 +38,28 @@ class Database(fixtures.Fixture):
                                          delete=False) as test_file:
             # note the temp file gets deleted by the NestedTempfile fixture.
             self.db_file = test_file.name
-        objects.IMPL.cleanup()
+        self.engine = session.get_engine()
+        # make sure the current connection is cleaned up.
+        self.engine.dispose()
+        session.cleanup()
 
     def setUp(self):
         super(Database, self).setUp()
         self.configure()
-        self.addCleanup(objects.IMPL.cleanup)
-        models.Base.metadata.create_all(objects.IMPL.get_engine())
-        objects.IMPL.get_engine().connect()
+        self.addCleanup(self.engine.dispose)
+        self.engine = session.get_engine()
+        models.Base.metadata.create_all(self.engine)
+        self.engine.connect()
         objects.load()
 
     def configure(self):
-        options.cfg.set_defaults(options.database_opts,
-                                 sqlite_synchronous=False)
-        options.set_defaults(cfg.CONF,
-                             connection='sqlite:///%s' % self.db_file,
+        session.set_defaults(sql_connection="sqlite:///%s" % self.db_file,
                              sqlite_db=self.db_file)
+        cfg.CONF.set_default('sqlite_synchronous', False)
 
 
 def get_dummy_session():
-    return objects.IMPL.get_session()
+    return session.get_session()
 
 
 def create_models_from_data(model_cls, data, ctx):
