@@ -14,11 +14,14 @@
 
 """API for interfacing with Solum Worker."""
 
-from oslo_config import cfg
-
+from oslo.config import cfg
 from solum.common.rpc import service
 
 
+STATES = (PENDING, BUILDING, ERROR, COMPLETE) = (
+    'PENDING', 'BUILDING', 'ERROR', 'COMPLETE')
+
+
 class API(service.API):
     def __init__(self, transport=None, context=None):
         cfg.CONF.import_opt('topic', 'solum.worker.config',
@@ -26,17 +29,9 @@ class API(service.API):
         super(API, self).__init__(transport, context,
                                   topic=cfg.CONF.worker.topic)
 
-    def build_app(self, verb, build_id, git_info, ports, name, base_image_id,
-                  source_format, image_format, assembly_id, workflow,
-                  test_cmd=None, run_cmd=None, du_id=None):
-        self._cast(verb, build_id=build_id, git_info=git_info, ports=ports,
+    def build(self, build_id, source_uri, name, base_image_id,
+              source_format, image_format, assembly_id=None):
+        self._cast('build', build_id=build_id, source_uri=source_uri,
                    name=name, base_image_id=base_image_id,
                    source_format=source_format, image_format=image_format,
-                   assembly_id=assembly_id, workflow=workflow,
-                   test_cmd=test_cmd, run_cmd=run_cmd, du_id=du_id)
-
-    def build_lp(self, image_id, git_info, name, source_format, image_format,
-                 artifact_type):
-        self._cast('build_lp', image_id=image_id, git_info=git_info, name=name,
-                   source_format=source_format, image_format=image_format,
-                   artifact_type=artifact_type)
+                   assembly_id=assembly_id)
